' OptusNet Usage Monitor v3.1
' Written by RaveRod (raverod@mantrasoftware.net)
'
' Original script written by dx and kop48.
'
' History:
'	v1.0 : Original dx script.
'	v2.0b: Modified by kop48 to include average usage.
'	v3.0 : Modified by RaveRod to download page ONCE and then read all information from there.
'	       Added function to get the time that usage was last updated.
'	       Added function to calculate how much usage is left per day (based on the per month function of kop48).
'	v3.1 : Fixed month size check to read end date from Optus Usage file.

' Configuration.
username = "USERNAME"
password = "PASSWORD"

' Gets the current OptusNet usage.
Function Get_Usage
	contents = Read_File()
	leftMark = instr( contents, "usage=" ) 
	leftMark = leftMark +6
	rightMark = instr( leftMark, contents, "MB" )
	Get_Usage = trim(mid( contents, leftMark, (rightMark-leftMark)))
End Function

' Gets the current plan size.
Function Get_PlanSize
	contents = Read_File()
	leftMark = instr( contents, "plan_limit=" ) 
	leftMark = leftMark +11
	rightMark = instr( leftMark, contents, "MB" )
	Get_PlanSize = trim(mid( contents, leftMark, (rightMark-leftMark)))
end function

' Gets the time when the usage was updated.
Function Get_Time
	contents = Read_File()

	leftMark = instr( contents, "last=" )
	leftMark = leftMark +5

	rightMark = instr( leftMark, contents, "-" )
	LastY = trim(mid( contents, leftMark+2, (rightMark-leftMark-2)))

	leftMark = leftMark + (rightMark-leftMark+1)
	rightMark = instr( leftMark, contents, "-" )
	LastM = trim(mid( contents, leftMark, (rightMark-leftMark)))

	leftMark = leftMark + (rightMark-leftMark+1)
	rightMark = instr( leftMark, contents, " " )
	LastD = trim(mid( contents, leftMark, (rightMark-leftMark)))

	leftMark = leftMark + (rightMark-leftMark+1)
	rightMark = instr( leftMark, contents, ":" )
	LastH = trim(mid( contents, leftMark, (rightMark-leftMark)))
	If LastH > 12 Then
		LastH = LastH -12
		AMPM = "PM"
	Else
		AMPM = "AM"
	End If

	leftMark = leftMark + (rightMark-leftMark+1)
	rightMark = instr( leftMark, contents, ":" )
	LastDay = trim(mid( contents, leftMark, (rightMark-leftMark)))

	leftMark = leftMark + (rightMark-leftMark+1)
	LastMin = trim(mid( contents, leftMark, 2))

	Get_Time = LastH & ":" & LastDay & ":" & LastMin & AMPM & " " & LastD & "." & LastM & "." & LastY
End Function

' Tells how much usage you have left per day.
Function Calc_Day
	MaxUsage = Calc_Usage()
	CurUsage = Get_Usage()

	CalcUsage = Round(MaxUsage - CurUsage)

	If CalcUsage <= 0 Then
		Stat = " over"
	Else
		Stat = " under"
	End If

	Calc_Day = Replace(CalcUsage, "-", "") & "MB" & Stat
End Function

' This function will calculate what usage you should be at if you divided
' your monthly limit by the number of days in the current month, then 
' multiplying it by the date to give you an approximation. This is handy
' for regulating your bandwidth so that you've got some left at the end 
' of the month. :)
Function Calc_Usage
	contents = Read_File()

	leftMark = instr( contents, "end=" )
	leftMark = leftMark +12
	monthSize = trim(mid( contents, leftMark, 2))

	Calc_Usage = (Get_PlanSize/monthSize) * Day(Date)
End Function

' Get the current usage HTML and write it to a file.
' Note: This function should only be called at intervals of AT LEAST 15 minutes.
Function Get_HTML
	sURL = "https://myaccount.optusnet.com.au/mydatamonitor/usage.txt?login=" & username & "&passwd=" & password
	Dim objXMLHTTP,HTML
	Set objXMLHTTP = CreateObject("Microsoft.XMLHTTP")
	objXMLHTTP.Open "GET", sURL, False
	objXMLHTTP.Send
	HTML = objXMLHTTP.responseBody
	Set objRS = CreateObject("ADODB.Recordset")
	objRS.Fields.Append "txt", 200, 45000, &H00000080
	objRS.Open
	objRS.AddNew
	objRS.Fields("txt").AppendChunk HTML
	ReturnHTML = objRS("txt").Value
	objRS.Close
	Set objRS = Nothing
	Set objXMLHTTP = Nothing

	Set fs = CreateObject("Scripting.FileSystemObject")
	Set f = fs.CreateTextFile("optususage.txt",true)
	f.write(ReturnHTML)
	f.close
	Set f = Nothing
	Set fs = Nothing
End Function

' Read the contents of the downloaded OptusNet information.
Function Read_File
	Dim contents
	Set fs = CreateObject ("Scripting.FileSystemObject")
	If (fs.FileExists("optususage.txt")) Then
		Set filePath = fs.GetFile("optususage.txt")
		Set File = filePath.OpenAsTextStream (1, -2)
		contents = file.readall
		File.Close
		Set filePath = nothing
		Set fs = nothing
		Set File = nothing
	Else
		Get_HTML()
		Read_File()
	End If

	Read_File = contents
End Function